@@ -1,4 +1,4 @@
-# Tests for batch processing
+# Tests for batch processing -----------------------------------------------
 
 test_that("calc_batch processes multiple farms", {
   farms <- data.frame(
@@ -21,10 +21,28 @@ test_that("calc_batch processes multiple farms", {
 })
 
 test_that("calc_batch validates tier input", {
-  farms <- data.frame(FarmID = "A", Milk_litres = 500000)
+  # Use a minimal but valid 1-row dataset so the function reaches tier validation
+  farms <- data.frame(
+    FarmID = "A",
+    Year = "2025",
+    Milk_litres = 500000,
+    Cows_milking = 100,
+    stringsAsFactors = FALSE
+  )
 
-  expect_error(calc_batch(data = farms, tier = 3))
-  expect_error(calc_batch(data = data.frame()))
+  expect_error(
+    calc_batch(data = farms, tier = 3),
+    regexp = "`tier` must be 1 or 2|tier.*(1|2)",
+    ignore.case = TRUE
+  )
+})
+
+test_that("calc_batch validates empty input", {
+  expect_error(
+    calc_batch(data = data.frame()),
+    regexp = "zero rows|nrow\\(data\\) == 0|empty|must.*contain",
+    ignore.case = TRUE
+  )
 })
 
 test_that("calc_batch handles errors gracefully", {
@@ -35,7 +53,13 @@ test_that("calc_batch handles errors gracefully", {
     stringsAsFactors = FALSE
   )
 
-  result <- suppressMessages(calc_batch(data = farms, tier = 1))
+  result <- suppressMessages(
+    calc_batch(
+      data = farms,
+      tier = 1,
+      boundaries = set_system_boundaries("farm_gate")
+    )
+  )
 
   expect_equal(result$summary$n_farms_successful, 1)
   expect_equal(result$summary$n_farms_with_errors, 1)
